Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(177)

Unified Diff: chrome/browser/about_flags.h

Issue 1159433002: Switch nomenclature in about_flags.cc to not use "Experiments". (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase. Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/about_flags.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/about_flags.h
diff --git a/chrome/browser/about_flags.h b/chrome/browser/about_flags.h
index 055d8b5105ca03b5e9710782fab20e629248f689..dcff4a33fb0612ca00b05efc4ec2827218af5696 100644
--- a/chrome/browser/about_flags.h
+++ b/chrome/browser/about_flags.h
@@ -25,10 +25,10 @@ namespace about_flags {
class FlagsStorage;
// Experiment is used internally by about_flags to describe an experiment (and
// for testing).
// This is exposed only for testing.
-struct Experiment {
+struct Entry {
enum Type {
// An experiment with a single value. This is typically what you want.
SINGLE_VALUE,
@@ -129,21 +129,21 @@ bool AreSwitchesIdenticalToCurrentCommandLine(
// with the |kOsCrOSOwnerOnly| label should be enabled in the UI or not.
enum FlagAccess { kGeneralAccessFlagsOnly, kOwnerAccessToFlags };
-// Get the list of experiments. Experiments that are available on the current
-// platform are appended to |supported_experiments|; all other experiments are
-// appended to |unsupported_experiments|.
-void GetFlagsExperimentsData(FlagsStorage* flags_storage,
- FlagAccess access,
- base::ListValue* supported_experiments,
- base::ListValue* unsupported_experiments);
+// Get the list of entries. Entries that are available on the current platform
+// are appended to |supported_entries|; all other entries are appended to
+// |unsupported_entries|.
+void GetFlagsEntryData(FlagsStorage* flags_storage,
+ FlagAccess access,
+ base::ListValue* supported_entries,
+ base::ListValue* unsupported_entries);
// Returns true if one of the experiment flags has been flipped since startup.
bool IsRestartNeededToCommitChanges();
// Enables or disables the experiment with id |internal_name|.
-void SetExperimentEnabled(FlagsStorage* flags_storage,
- const std::string& internal_name,
- bool enable);
+void SetEntryEnabled(FlagsStorage* flags_storage,
+ const std::string& internal_name,
+ bool enable);
// Removes all switches that were added to a command line by a previous call to
// |ConvertFlagsToSwitches()|.
@@ -177,12 +177,12 @@ namespace testing {
// Clears internal global state, for unit tests.
void ClearState();
-// Sets the list of experiments. Pass in NULL to use the default set. This does
-// NOT take ownership of the supplied Experiments.
-void SetExperiments(const Experiment* e, size_t count);
+// Sets the list of entries. Pass in NULL to use the default set. This does
+// NOT take ownership of the supplied Entries.
+void SetEntries(const Entry* e, size_t count);
-// Returns the current set of experiments.
-const Experiment* GetExperiments(size_t* count);
+// Returns the current set of entries.
+const Entry* GetEntries(size_t* count);
// Separator used for multi values. Multi values are represented in prefs as
// name-of-experiment + kMultiSeparator + selected_index.
« no previous file with comments | « no previous file | chrome/browser/about_flags.cc » ('j') | no next file with comments »
@@ -25,10 +25,10 @@ namespace about_flags {
class FlagsStorage;
-// Experiment is used internally by about_flags to describe an experiment (and
+// Entry is used internally by about_flags to describe an experiment (and
// for testing).
// This is exposed only for testing.

Powered by Google App Engine
This is Rietveld 408576698